==> arrow-docs-0.8.1-sources.jar: arrow/optics/Pos$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Pos`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Pos`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`>> inline get()= arrow.optics.Iso(
  get = { pos: `arrow`.`optics`.`Pos` -> arrow.core.Tuple2(pos.`x`, pos.`y`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`> -> `arrow`.`optics`.`Pos`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Pos`.Companion.x: arrow.optics.Lens<`arrow`.`optics`.`Pos`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { pos: `arrow`.`optics`.`Pos` -> pos.`x` },
  set = { value: `kotlin`.`Int` ->
    { pos: `arrow`.`optics`.`Pos` ->
      pos.copy(`x` = value)
    }
  }
)

inline val `arrow`.`optics`.`Pos`.Companion.y: arrow.optics.Lens<`arrow`.`optics`.`Pos`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { pos: `arrow`.`optics`.`Pos` -> pos.`y` },
  set = { value: `kotlin`.`Int` ->
    { pos: `arrow`.`optics`.`Pos` ->
      pos.copy(`y` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y

==> arrow-docs-0.10.3-sources.jar: arrow/optics/Pos$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Pos`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Pos`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`>> inline get()= arrow.optics.Iso(
  get = { pos: `arrow`.`optics`.`Pos` -> arrow.core.Tuple2(pos.`x`, pos.`y`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`> -> `arrow`.`optics`.`Pos`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Pos`.Companion.x: arrow.optics.Lens<`arrow`.`optics`.`Pos`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { pos: `arrow`.`optics`.`Pos` -> pos.`x` },
  set = { pos: `arrow`.`optics`.`Pos`, value: `kotlin`.`Int` -> pos.copy(`x` = value) }
)

inline val `arrow`.`optics`.`Pos`.Companion.y: arrow.optics.Lens<`arrow`.`optics`.`Pos`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { pos: `arrow`.`optics`.`Pos` -> pos.`y` },
  set = { pos: `arrow`.`optics`.`Pos`, value: `kotlin`.`Int` -> pos.copy(`y` = value) }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Pos`>.x: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.x

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Pos`>.y: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Pos`.y
